# coding: utf-8
import os

from django.conf import settings
from django.core.exceptions import SuspiciousFileOperation
from django.utils._os import safe_join

from horizon import themes


class TionixThemeTemplateLoader(themes.ThemeTemplateLoader):
    """Themes can contain template overrides, so we need to check the
       theme directory first, before loading any of the standard templates.

       Refactored by https://review.openstack.org/#/c/317051/,
       also fixed bag when theme path is absolute
    """

    def get_template_sources(self, template_name):

        # If the cookie doesn't exist, set it to the default theme
        default_theme = themes.get_default_theme()
        theme = getattr(themes._local, 'theme', default_theme)
        # If the theme is not valid, check the default theme ...
        this_theme = themes.find_theme(theme) or themes.find_theme(default_theme)

        # If the theme is still not valid, then move along ...
        # these aren't the templates you are looking for
        if this_theme:

            try:
                this_theme_path = this_theme[2]
                if os.path.isabs(this_theme_path):
                    template_path = safe_join(
                        this_theme_path,
                        'templates'
                    )
                else:
                    # If this_theme_path is not absolute path,
                    # then check root_path or openstack ans path
                    template_path = safe_join(
                        getattr(
                            settings,
                            'ROOT_PATH',
                            os.path.abspath('openstack_dashboard')
                        ),
                        this_theme_path,
                        'templates'
                    )
                if not template_name.startswith('/'):
                    try:
                        yield safe_join(template_path, template_name)
                    except SuspiciousFileOperation:
                        yield os.path.join(
                            this_theme[2], 'templates', template_name
                        )
                elif template_name.find(template_path) != -1:
                    yield template_name
            except UnicodeDecodeError:
                # The template dir name wasn't valid UTF-8.
                raise
            except ValueError:
                # The joined path was located outside of template_dir.
                pass